@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: Logwatch.pm 312 2016-02-11 00:48:15Z bjorn1 $
+# $Id: Logwatch.pm,v 1.13 2005/09/12 22:13:10 bjorn Exp $
 
 package Logwatch;
 
@@ -200,7 +200,7 @@ sub TotalCountOrder(\%;&) {
             }
         }
         my $count = $BB <=> $AA;
-
+        
         return $count if $count;
         if (ref $coderef) {
             $a = $A;
@@ -347,7 +347,7 @@ sub LookupIP {
 This function merely prints out some information about --range to STDERR.
 
 =cut
-
+    
 sub RangeHelpDM {
    eval "use Date::Manip"; my $hasDM = $@ ? 0 : 1;
 
@@ -356,9 +356,8 @@ sub RangeHelpDM {
        print STDERR "of the valid --range parameters.\n";
    } else {
        print STDERR "\nThis system does not have Date::Manip module loaded, and therefore\n";
-       print STDERR "the only valid --range parameters are \"yesterday\", \"today\", or \"all\".\n";
+       print STDERR "the only valid --range parameters are 'yesterday', 'today', or 'all'.\n";
        print STDERR "The Date::Manip module can be installed by using either of:\n";
-       print STDERR "   apt-get install libdate-manip-perl (recommended on Debian)'\n";
        print STDERR "   cpan -i 'Date::Manip'\n";
        print STDERR "   perl -MCPAN -e 'install Date::Manip'\n";
        print STDERR "\nFollowing is a description of the full capabilities available if\n";
@@ -370,9 +369,9 @@ sub RangeHelpDM {
 The format of the range option is:
     --range \"date_range [period]\"
 
-Parameter date_range (and optional period) must be enclosed in double quotes
-if it is more than one word.  The default for date_range is \"yesterday\".
-Valid instances of date_range have one of the following formats:
+Parameter date_range (and optional period) must be enclosed in quotes if it is
+more than one word.  The default for date_range is \"yesterday\". Valid
+instances of date_range have one of the following formats:
 
    yesterday
    today
@@ -397,14 +396,14 @@ Examples:
 
    --range today
    --range yesterday
-   --range \"4 hours ago for that hour\"
-   --range \"-3 days\"
-   --range \"since 2 hours ago for those hours\"
-   --range \"between -10 days and -2 days\"
-   --range \"Apr 15, 2005\"
-   --range \"first Monday in May\"
-   --range \"between 4/23/2005 and 4/30/2005\"
-   --range \"2005/05/03 10:24:17 for that second\"
+   --range '4 hours ago for that hour'
+   --range '-3 days'
+   --range 'since 2 hours ago for those hours'
+   --range 'between -10 and -2 days'
+   --range 'Apr 15, 2005'
+   --range 'first Monday in May'
+   --range 'between 4/23/2005 and 4/30/2005'
+   --range '2005/05/03 10:24:17 for that second'
 
 (The last entry might be used by someone debugging a log or filter.)
 
@@ -427,7 +426,7 @@ This function returns the period, which is the part after the "for (those|that|t
 in a range
 
 =cut
-
+    
 sub GetPeriod {
 
    my $range = lc $ENV{"LOGWATCH_DATE_RANGE"} || "yesterday";
@@ -455,13 +454,6 @@ sub TimeBuild {
    my $time = time;
    eval "use Date::Manip"; my $hasDM = $@ ? 0 : 1;
 
-   if ($hasDM) {
-      eval 'Date_TimeZone();';
-      if ($@) {
-         die "ERROR: Date::Manip unable to determine TimeZone.\n\nExecute the following command in a shell prompt:\n\tperldoc Date::Manip\nThe section titled TIMEZONES describes valid TimeZones\nand where they can be defined.\n";
-      }
-   }
-
    my $range = lc $ENV{"LOGWATCH_DATE_RANGE"} || "yesterday";
    my $period = GetPeriod;
    $range =~ s/for\s+(?:those|that|this)\s+((year|month|day|hour|minute|second)s?)\s*$//;
@@ -534,11 +526,13 @@ sub TimeBuild {
 This function returns a regexp to filter by date/time
 
 =cut
-
+    
 
 sub TimeFilter {
    my ($format) = $_[0];
 
+   eval "use Date::Manip"; my $hasDM = $@ ? 0 : 1;
+    
    my $SearchDate;
 
    my $range = lc $ENV{"LOGWATCH_DATE_RANGE"} || "yesterday";
@@ -563,7 +557,7 @@ sub TimeFilter {
            $format =~ s/%a/.../;
            $format =~ s/%d/../;
            $format =~ s/%e/../;
-           if ($period eq 'month') {last;}
+           if ($period eq 'month') {last;}      
            $format =~ s/%b/.../;
            $format =~ s/%m/../;
            if ($period eq 'year') {last;}
@@ -572,7 +566,7 @@ sub TimeFilter {
    }
 
    $SearchDate .= "(";
-
+    
    for my $time (@time_t) {
         if ($time) {
            $SearchDate .= strftime($format, localtime($time)) . "|";
